# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`autoconfigmail`](#autoconfigmail): Main class to create autoconfiguring services
* [`autoconfigmail::autoconfig`](#autoconfigmailautoconfig): This class implements autoconfig by creating a XML file whit the mail configuration  For details about autoconfig see: https://developer.mozi
* [`autoconfigmail::autodiscover`](#autoconfigmailautodiscover): This class implements autodiscover by creating a XML file with available mail services  For details about autodiscover see: http://technet.mi
* [`autoconfigmail::vhost::apache`](#autoconfigmailvhostapache): internal class that installs an apache vhost to serve xml files.

## Classes

### <a name="autoconfigmail"></a>`autoconfigmail`

Main class to create autoconfiguring
services

#### Parameters

The following parameters are available in the `autoconfigmail` class:

* [`mailserver`](#mailserver)
* [`documentroot`](#documentroot)
* [`apache_config`](#apache_config)
* [`enable_autodiscover`](#enable_autodiscover)
* [`enable_autoconfig`](#enable_autoconfig)
* [`vhost_type`](#vhost_type)
* [`autoconfig_incoming`](#autoconfig_incoming)
* [`autoconfig_outgoing`](#autoconfig_outgoing)
* [`autoconfig_documentation`](#autoconfig_documentation)
* [`autodiscover_protocols`](#autodiscover_protocols)

##### <a name="mailserver"></a>`mailserver`

Data type: `String`

the mailserver to connect to
defaults to: $::fqdn
Remark: if you specify 'hostname' on $incoming/$outgoing
Hash, you can overwrite this default for specified service.

Default value: `$::fqdn`

##### <a name="documentroot"></a>`documentroot`

Data type: `String`

the document root, where to place the file
defaults to: '/var/www/html'

Default value: `'/var/www/html'`

##### <a name="apache_config"></a>`apache_config`

Data type: `Optional[String]`

Path to write an apache config snippet. For inclusion in an apache
vhost. This file is only needed if you are configure you're vhost
not using this module. The vhost generated with this module
uses an implicit configuration of these settings.

Default value: ``undef``

##### <a name="enable_autodiscover"></a>`enable_autodiscover`

Data type: `Boolean`

if true, includes ::autoconfigmail::autodiscover
defaults to true

Default value: ``true``

##### <a name="enable_autoconfig"></a>`enable_autoconfig`

Data type: `Boolean`

= true,
if true, includes ::autoconfigmail::autoconfig
defaults to true

Default value: ``true``

##### <a name="vhost_type"></a>`vhost_type`

Data type: `String`

= 'none',
the vhost type to install
currently 'apache' and 'none' is supported
defaults to 'none'

Default value: `'none'`

##### <a name="autoconfig_incoming"></a>`autoconfig_incoming`

Data type: `Array`

see ::autoconfigmail::autoconfig for details
and example

##### <a name="autoconfig_outgoing"></a>`autoconfig_outgoing`

Data type: `Array`

see ::autoconfigmail::autoconfig for details
and example

##### <a name="autoconfig_documentation"></a>`autoconfig_documentation`

Data type: `Array`

see ::autoconfigmail::autoconfig for details
and example

Default value: `[]`

##### <a name="autodiscover_protocols"></a>`autodiscover_protocols`

Data type: `Array`

see ::autoconfigmail::autodiscover for details
and example

### <a name="autoconfigmailautoconfig"></a>`autoconfigmail::autoconfig`

This class implements autoconfig
by creating a XML file whit the mail configuration

For details about autoconfig see:
https://developer.mozilla.org/en-US/docs/Thunderbird/Autoconfiguration
and:
https://developer.mozilla.org/en-US/docs/Thunderbird/Autoconfiguration/FileFormat/HowTo.

#### Parameters

The following parameters are available in the `autoconfigmail::autoconfig` class:

* [`mailserver`](#mailserver)
* [`documentroot`](#documentroot)
* [`incoming`](#incoming)
* [`outgoing`](#outgoing)
* [`documentation`](#documentation)
* [`provider`](#provider)
* [`domain`](#domain)
* [`shortname`](#shortname)
* [`displayname`](#displayname)
* [`default_authentication`](#default_authentication)
* [`default_username`](#default_username)

##### <a name="mailserver"></a>`mailserver`

Data type: `String`

the mailserver to connect to
defaults to: $autoconfigmail::mailserver
Remark: if you specify 'hostname' on $incoming/$outgoing
Hash, you can overwrite this default for specified service.

Default value: `$autoconfigmail::mailserver`

##### <a name="documentroot"></a>`documentroot`

Data type: `String`

the document root, where to place the file
defaults to: $autoconfigmail::documentroot

Default value: `$autoconfigmail::documentroot`

##### <a name="incoming"></a>`incoming`

Data type: `Array`

Array of Hashes of services available for incoming mail
defaults to $autoconfigmail::autoconfig_incoming

Example in hiera for imap service:
  autoconfigmail::autooconfig::incoming:
    - type:           'imap'
      port:           '143'
      sockettype:     'STARTTLS'
      authentication: 'password-encrypted'
      username:       '%EMAILADDRESS%'  # use if you login without domain %EMAILLOCALPART%

Remark: if you specify hostname, you can overwrite the default
$mailserver for a service.

Default value: `$autoconfigmail::autoconfig_incoming`

##### <a name="outgoing"></a>`outgoing`

Data type: `Array`

Array of Hashes of services available for sending mail
defaults to $autoconfigmail::autoconfig_outgoing

Example in hiera for smtp service:
  # Remark: if authentication/username is not specified,
  # default is taken.
  autoconfigmail::autoconfig::outgoing:
    - type:           'smtp'
      port:           '25'
      sockettype:     'STARTTLS'
      authentication: 'password-encrypted'
      username:       '%EMAILADDRESS%'  # use if you login without domain %EMAILLOCALPART%

Remark: if you specify hostname, you can overwrite the default
$mailserver for a service.

Default value: `$autoconfigmail::autoconfig_outgoing`

##### <a name="documentation"></a>`documentation`

Data type: `Array`

= $autoconfigmail::autoconfig_documentation_default,
Array of Hashes to specify Url's about mail.
  autoconfigmail::autoconfig::documentation:
    - url: 'https://www.cirrax.com'
      descriptions:
        de: 'Cirrax Webseite'
        en: 'Website of Cirrax'

Default value: `$autoconfigmail::autoconfig_documentation`

##### <a name="provider"></a>`provider`

Data type: `String`

id of the email provider (defaults to $::fqdn)

Default value: `$::fqdn`

##### <a name="domain"></a>`domain`

Data type: `String`

domain of the email provider (defaults to $::domain)

Default value: `$::domain`

##### <a name="shortname"></a>`shortname`

Data type: `String`

shortname of the email provider (defaults to $::hostname)

Default value: `$::hostname`

##### <a name="displayname"></a>`displayname`

Data type: `String`

diplayname of the email provider (defaults to "Mailserver ${::fqdn}")

Default value: `"Mailserver ${::fqdn}"`

##### <a name="default_authentication"></a>`default_authentication`

Data type: `String`

default authentication to take for incoming and outgoing if not
specified there

Default value: `'password-encrypted'`

##### <a name="default_username"></a>`default_username`

Data type: `String`

default username to take for incoming and outgoing if not
specified there

Default value: `'%EMAILADDRESS%'`

### <a name="autoconfigmailautodiscover"></a>`autoconfigmail::autodiscover`

This class implements autodiscover
by creating a XML file with available mail services

For details about autodiscover see:
http://technet.microsoft.com/en-us/library/bb124251.aspx
and
http://msdn.microsoft.com/en-us/library/dd899340%28v=exchg.140%29

Parameters:

#### Parameters

The following parameters are available in the `autoconfigmail::autodiscover` class:

* [`mailserver`](#mailserver)
* [`documentroot`](#documentroot)
* [`protocols`](#protocols)

##### <a name="mailserver"></a>`mailserver`

Data type: `String`

the mailserver to connect to
defaults to: $autoconfigmail::mailserver
Remark: if you specify 'hostname' on $incoming/$outgoing
Hash, you can overwrite this default for specified service.

Default value: `$autoconfigmail::mailserver`

##### <a name="documentroot"></a>`documentroot`

Data type: `String`

the document root, where to place the file
defaults to: $autoconfigmail::documentroot

Default value: `$autoconfigmail::documentroot`

##### <a name="protocols"></a>`protocols`

Data type: `Array`

Array of Hashes of services available for incoming mail
defaults to $autoconfigmail::autodiscover_protocols

Example in hiera for imap service:
autoconfigmail::autodiscover::protocols:
  - type: 'IMAP'
    port: '993'

Default value: `$autoconfigmail::autodiscover_protocols`

### <a name="autoconfigmailvhostapache"></a>`autoconfigmail::vhost::apache`

internal class that installs an apache vhost
to serve xml files.

#### Parameters

The following parameters are available in the `autoconfigmail::vhost::apache` class:

* [`servername`](#servername)
* [`serveraliases`](#serveraliases)
* [`enable_autoconfig_alias`](#enable_autoconfig_alias)
* [`apache_vhost_defaults`](#apache_vhost_defaults)
* [`documentroot`](#documentroot)
* [`ssl`](#ssl)
* [`ssl_cert`](#ssl_cert)
* [`ssl_key`](#ssl_key)
* [`ssl_chain`](#ssl_chain)
* [`vhost_add`](#vhost_add)
* [`create_resources`](#create_resources)

##### <a name="servername"></a>`servername`

Data type: `String`

main servername defaults to $autoconfigmail::mailserver

Default value: `$autoconfigmail::mailserver`

##### <a name="serveraliases"></a>`serveraliases`

Data type: `Array`

serveraliases, defaults to []

Default value: `[]`

##### <a name="enable_autoconfig_alias"></a>`enable_autoconfig_alias`

Data type: `Boolean`

if true (default) adds a serveralias 'autoconfig.*'
for autoconfig.

Default value: ``true``

##### <a name="apache_vhost_defaults"></a>`apache_vhost_defaults`

Data type: `Hash`

other parameters to ::apache::vhost
defaults to {}

Default value: `{}`

##### <a name="documentroot"></a>`documentroot`

Data type: `String`

the document root of the webwerver
defaults to: $autoconfigmail::documentroot

Default value: `$autoconfigmail::documentroot`

##### <a name="ssl"></a>`ssl`

Data type: `Boolean`

If true, use ssl (defaults to false)
If true, you also need to set cert, key and chain.

Default value: ``false``

##### <a name="ssl_cert"></a>`ssl_cert`

Data type: `String`

ssl cert to use

Default value: `''`

##### <a name="ssl_key"></a>`ssl_key`

Data type: `String`

ssl key to use

Default value: `''`

##### <a name="ssl_chain"></a>`ssl_chain`

Data type: `String`

ssl chain to use

Default value: `''`

##### <a name="vhost_add"></a>`vhost_add`

Data type: `Hash`

Hash to add additional parameters to ::apache::vhost creation

Example in hiera to add an additional include file:
  autoconfigmail::vhost::apache::vhost_add:
    additional_includes:
        - '/etc/letsencrypt/apache.conf'

Default value: `{}`

##### <a name="create_resources"></a>`create_resources`

Data type: `Hash`

a Hash of Hashes to create additional resources eg. to
retrieve a certificate.
Defaults to {} (do not create any additional resources)
Example (hiera):

autoconfigmail::vhost::apache::create_resources:
  sslcert::get_cert:
    get_my_postfix_cert:
      private_key_path: '/etc/postfixadmin/ssl/key.pem'
      cert_path: '/etc/postfixadmin/ssl/cert.pem'

Will result in  executing:

sslcert::get_cert{'get_my_postfix_cert':
  private_key_path => '/etc/postfixadmin/ssl/key.pem'
  cert_path        => '/etc/postfixadmin/ssl/cert.pem'
}

Default value: `{}`

